﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using NLua;

namespace NLua_Playground
{
    class Program
    {
        const string tableLoad = 
@"--// The Load Function 
function table.load( sfile )
   
   if string.sub( sfile,-3,-1 ) == ""--|\\"" then
      tables,err = loadstring( sfile )
   else
      tables,err = loadfile( sfile )
   end
   if err then return _,err
   end
   tables = tables()
   for idx = 1,#tables do
      local tolinkv,tolinki = {},{}
      for i,v in pairs( tables[idx] ) do
         if type( v ) == ""table"" and tables[v[1]] then
            table.insert( tolinkv,{ i,tables[v[1]] } )
         end
         if type( i ) == ""table"" and tables[i[1]] then
            table.insert( tolinki,{ i,tables[i[1]] } )
         end
      end
      
      for _,v in ipairs( tolinkv ) do
         tables[idx][v[1]] = v[2]
      end
      
      for _,v in ipairs( tolinki ) do
         tables[idx][v[2]],tables[idx][v[1]] =  tables[idx][v[1]],nil
      end
   end
   return tables[1]
end";
            

        static void Main(string[] args)
        {

            Lua lua = new Lua();
            lua.LoadCLRPackage();

            string engineFileName = "0.7L 20V DOHC TurboRev0.lua";

            //Use the same table.load function that automation uses
            lua.DoString(tableLoad);
            //Execute the load string, providing thee example filename above
            lua.DoString("engineInfo = table.load(\"" + engineFileName + "\")");

            //Get the engineInfo from the global lua state
            LuaTable engineInfo = (LuaTable)lua["engineInfo"];

            //Get the results from the engine info
            LuaTable results = (LuaTable)engineInfo["Results"];

            //Get the rpm from the results (rather than RPMLimit in engine info)
            double maxRPM = (double)results["rpm"];

            //Get the power curves
            LuaTable curves = (LuaTable)results["Curves"];

            double peakPower = (double)results["PeakPower"];

            //Now we can do a loop and extract each one
            //maxRPM - 500 (as 500 is the starting rpm)
            for (int i = 1; i < (int)((maxRPM - 500) / 100.0); i++)
            {
                LuaTable rpmStat = (LuaTable)curves[i];

                //Lua indexes from 1
                //The curves data is as follows:
                //rpmStat[1]; RPM
                //rpmStat[2]; Torque
                //rpmStat[3]; Power
                //rpmStat[4]; Economy
                //rpmStat[5]; Boost in bar (Absolute I believe)

                double rpm = (double)rpmStat[1];
                double power = (double)rpmStat[3];
                double torque = (double)rpmStat[2];

                Console.WriteLine("RPM {0,-5} - {1:#.#} kW - {2:#.#} Nm", rpm, power, torque);
            }


            Console.Read();
        }
    }
}
